# jnotice

Prebuilt JupyterLab extension (federated) that polls `.jnotice.txt` and `.jnotice.sticky.txt` and shows toast notifications.
The text files to display can also be configured via JupyterLab's `--ServerApp.tornado_settings=` option.

- JupyterLab 4.x
- Install: `pip install jnotice`

